court\_scraper.platforms.ia.pages package
=========================================

Submodules
----------

court\_scraper.platforms.ia.pages.case\_detail module
-----------------------------------------------------

.. automodule:: court_scraper.platforms.ia.pages.case_detail
   :members:
   :undoc-members:
   :show-inheritance:

court\_scraper.platforms.ia.pages.home module
---------------------------------------------

.. automodule:: court_scraper.platforms.ia.pages.home
   :members:
   :undoc-members:
   :show-inheritance:

court\_scraper.platforms.ia.pages.search\_results module
--------------------------------------------------------

.. automodule:: court_scraper.platforms.ia.pages.search_results
   :members:
   :undoc-members:
   :show-inheritance:

court\_scraper.platforms.ia.pages.search\_selection module
----------------------------------------------------------

.. automodule:: court_scraper.platforms.ia.pages.search_selection
   :members:
   :undoc-members:
   :show-inheritance:

court\_scraper.platforms.ia.pages.search\_trial\_court module
-------------------------------------------------------------

.. automodule:: court_scraper.platforms.ia.pages.search_trial_court
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: court_scraper.platforms.ia.pages
   :members:
   :undoc-members:
   :show-inheritance:
